@@ -31,7 +31,7 @@ class Sorter(NamedTuple):
 class WithSorting:
     """With sorting mixin."""
 
-    _request_data: Dict
+    request_data: Dict
 
     def sort_by(self, sorter_obj: Sorter):
         """Sort by sorter.
@@ -39,7 +39,7 @@ class WithSorting:
         :param sorter_obj: sorter object
         :return: self object
         """
-        sort_by = self._request_data.get('sort_by')
+        sort_by = self.request_data.get('sort_by')
         if sort_by is None:
             sort_by = str(sorter_obj)
         else:
@@ -47,5 +47,5 @@ class WithSorting:
                 sort_by=sort_by,
                 new_field=str(sorter_obj),
             )
-        self._request_data['sort_by'] = sort_by
+        self.request_data['sort_by'] = sort_by
         return self
